redvox.api900 API documentation

# Module `redvox.api900`

## Sub-modules

`redvox.api900.concat`

  This module contains functions for concatenating multiple WrappedRedvoxPackets together.

`redvox.api900.constants`

  This modules contains constants used throughout the SDK.

`redvox.api900.deprecation`

  This module provides functions for gracefully deprecating functionality in this SDK.

`redvox.api900.exceptions`

  This module contains custom exceptions for API 900.

`redvox.api900.lib`
`redvox.api900.location_analyzer`

  finds a station's best location and compare it against a surveyed point if one is provided station location data can be loaded from rdvxz files or …

`redvox.api900.migrations`

  This module provides functions and utilities for slowly migrating API 900 towards API 1000.

`redvox.api900.qa`
`redvox.api900.reader`

  This module provides functions and classes for working with RedVox API 900 data.

`redvox.api900.reader_utils`

  This module provides utility functions that are used by the reader but generally will not be used directly by end users.

`redvox.api900.sensors`
`redvox.api900.stat_utils`

  utilities to calculate std deviation, mean, and median for arrays

`redvox.api900.summarize`

  This module contains functions and classes for summarizing ranges of redvox data.

`redvox.api900.timesync`
`redvox.api900.types`

  This module provides convenience types for RedVox data types.

`redvox.api900.wrapped_redvox_packet`

  This module contains classes and methods for working with WrappedRedvoxPackets